"""
Setup script for boto3-stubs.

Copyright 2025 Vlad Emelianov
"""

from pathlib import Path

from setuptools import setup  # type: ignore

LONG_DESCRIPTION = (Path(__file__).parent / "README.md").read_text()

setup(
    name="boto3-stubs",
    version="1.36.4",
    packages=["boto3-stubs"],
    url="https://github.com/youtype/mypy_boto3_builder",
    license="MIT License",
    author="Vlad Emelianov",
    author_email="vlad.emelianov.nz@gmail.com",
    description="Type annotations for boto3 1.36.4 generated with mypy-boto3-builder 8.8.0",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Environment :: Console",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
        "Programming Language :: Python :: 3.14",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: Implementation :: CPython",
        "Typing :: Stubs Only",
    ],
    keywords="boto3 boto3-stubs type-annotations typeshed autocomplete",
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    package_data={"boto3-stubs": ["py.typed", "*.pyi", "*/*.pyi"]},
    python_requires=">=3.8",
    project_urls={
        "Documentation": "https://youtype.github.io/boto3_stubs_docs/",
        "Source": "https://github.com/youtype/mypy_boto3_builder",
        "Tracker": "https://github.com/youtype/mypy_boto3_builder/issues",
    },
    install_requires=[
        "botocore-stubs",
        "types-s3transfer",
        'typing-extensions>=4.1.0; python_version<"3.12"',
    ],
    extras_require={
        "full": ["boto3-stubs-full>=1.36.0, <1.37.0"],
        "boto3": ["boto3==1.36.4"],
        "all": [
            "mypy-boto3-accessanalyzer>=1.36.0, <1.37.0",
            "mypy-boto3-account>=1.36.0, <1.37.0",
            "mypy-boto3-acm>=1.36.0, <1.37.0",
            "mypy-boto3-acm-pca>=1.36.0, <1.37.0",
            "mypy-boto3-amp>=1.36.0, <1.37.0",
            "mypy-boto3-amplify>=1.36.0, <1.37.0",
            "mypy-boto3-amplifybackend>=1.36.0, <1.37.0",
            "mypy-boto3-amplifyuibuilder>=1.36.0, <1.37.0",
            "mypy-boto3-apigateway>=1.36.0, <1.37.0",
            "mypy-boto3-apigatewaymanagementapi>=1.36.0, <1.37.0",
            "mypy-boto3-apigatewayv2>=1.36.0, <1.37.0",
            "mypy-boto3-appconfig>=1.36.0, <1.37.0",
            "mypy-boto3-appconfigdata>=1.36.0, <1.37.0",
            "mypy-boto3-appfabric>=1.36.0, <1.37.0",
            "mypy-boto3-appflow>=1.36.0, <1.37.0",
            "mypy-boto3-appintegrations>=1.36.0, <1.37.0",
            "mypy-boto3-application-autoscaling>=1.36.0, <1.37.0",
            "mypy-boto3-application-insights>=1.36.0, <1.37.0",
            "mypy-boto3-application-signals>=1.36.0, <1.37.0",
            "mypy-boto3-applicationcostprofiler>=1.36.0, <1.37.0",
            "mypy-boto3-appmesh>=1.36.0, <1.37.0",
            "mypy-boto3-apprunner>=1.36.0, <1.37.0",
            "mypy-boto3-appstream>=1.36.0, <1.37.0",
            "mypy-boto3-appsync>=1.36.0, <1.37.0",
            "mypy-boto3-apptest>=1.36.0, <1.37.0",
            "mypy-boto3-arc-zonal-shift>=1.36.0, <1.37.0",
            "mypy-boto3-artifact>=1.36.0, <1.37.0",
            "mypy-boto3-athena>=1.36.0, <1.37.0",
            "mypy-boto3-auditmanager>=1.36.0, <1.37.0",
            "mypy-boto3-autoscaling>=1.36.0, <1.37.0",
            "mypy-boto3-autoscaling-plans>=1.36.0, <1.37.0",
            "mypy-boto3-b2bi>=1.36.0, <1.37.0",
            "mypy-boto3-backup>=1.36.0, <1.37.0",
            "mypy-boto3-backup-gateway>=1.36.0, <1.37.0",
            "mypy-boto3-backupsearch>=1.36.0, <1.37.0",
            "mypy-boto3-batch>=1.36.0, <1.37.0",
            "mypy-boto3-bcm-data-exports>=1.36.0, <1.37.0",
            "mypy-boto3-bcm-pricing-calculator>=1.36.0, <1.37.0",
            "mypy-boto3-bedrock>=1.36.0, <1.37.0",
            "mypy-boto3-bedrock-agent>=1.36.0, <1.37.0",
            "mypy-boto3-bedrock-agent-runtime>=1.36.0, <1.37.0",
            "mypy-boto3-bedrock-data-automation>=1.36.0, <1.37.0",
            "mypy-boto3-bedrock-data-automation-runtime>=1.36.0, <1.37.0",
            "mypy-boto3-bedrock-runtime>=1.36.0, <1.37.0",
            "mypy-boto3-billing>=1.36.0, <1.37.0",
            "mypy-boto3-billingconductor>=1.36.0, <1.37.0",
            "mypy-boto3-braket>=1.36.0, <1.37.0",
            "mypy-boto3-budgets>=1.36.0, <1.37.0",
            "mypy-boto3-ce>=1.36.0, <1.37.0",
            "mypy-boto3-chatbot>=1.36.0, <1.37.0",
            "mypy-boto3-chime>=1.36.0, <1.37.0",
            "mypy-boto3-chime-sdk-identity>=1.36.0, <1.37.0",
            "mypy-boto3-chime-sdk-media-pipelines>=1.36.0, <1.37.0",
            "mypy-boto3-chime-sdk-meetings>=1.36.0, <1.37.0",
            "mypy-boto3-chime-sdk-messaging>=1.36.0, <1.37.0",
            "mypy-boto3-chime-sdk-voice>=1.36.0, <1.37.0",
            "mypy-boto3-cleanrooms>=1.36.0, <1.37.0",
            "mypy-boto3-cleanroomsml>=1.36.0, <1.37.0",
            "mypy-boto3-cloud9>=1.36.0, <1.37.0",
            "mypy-boto3-cloudcontrol>=1.36.0, <1.37.0",
            "mypy-boto3-clouddirectory>=1.36.0, <1.37.0",
            "mypy-boto3-cloudformation>=1.36.0, <1.37.0",
            "mypy-boto3-cloudfront>=1.36.0, <1.37.0",
            "mypy-boto3-cloudfront-keyvaluestore>=1.36.0, <1.37.0",
            "mypy-boto3-cloudhsm>=1.36.0, <1.37.0",
            "mypy-boto3-cloudhsmv2>=1.36.0, <1.37.0",
            "mypy-boto3-cloudsearch>=1.36.0, <1.37.0",
            "mypy-boto3-cloudsearchdomain>=1.36.0, <1.37.0",
            "mypy-boto3-cloudtrail>=1.36.0, <1.37.0",
            "mypy-boto3-cloudtrail-data>=1.36.0, <1.37.0",
            "mypy-boto3-cloudwatch>=1.36.0, <1.37.0",
            "mypy-boto3-codeartifact>=1.36.0, <1.37.0",
            "mypy-boto3-codebuild>=1.36.0, <1.37.0",
            "mypy-boto3-codecatalyst>=1.36.0, <1.37.0",
            "mypy-boto3-codecommit>=1.36.0, <1.37.0",
            "mypy-boto3-codeconnections>=1.36.0, <1.37.0",
            "mypy-boto3-codedeploy>=1.36.0, <1.37.0",
            "mypy-boto3-codeguru-reviewer>=1.36.0, <1.37.0",
            "mypy-boto3-codeguru-security>=1.36.0, <1.37.0",
            "mypy-boto3-codeguruprofiler>=1.36.0, <1.37.0",
            "mypy-boto3-codepipeline>=1.36.0, <1.37.0",
            "mypy-boto3-codestar-connections>=1.36.0, <1.37.0",
            "mypy-boto3-codestar-notifications>=1.36.0, <1.37.0",
            "mypy-boto3-cognito-identity>=1.36.0, <1.37.0",
            "mypy-boto3-cognito-idp>=1.36.0, <1.37.0",
            "mypy-boto3-cognito-sync>=1.36.0, <1.37.0",
            "mypy-boto3-comprehend>=1.36.0, <1.37.0",
            "mypy-boto3-comprehendmedical>=1.36.0, <1.37.0",
            "mypy-boto3-compute-optimizer>=1.36.0, <1.37.0",
            "mypy-boto3-config>=1.36.0, <1.37.0",
            "mypy-boto3-connect>=1.36.0, <1.37.0",
            "mypy-boto3-connect-contact-lens>=1.36.0, <1.37.0",
            "mypy-boto3-connectcampaigns>=1.36.0, <1.37.0",
            "mypy-boto3-connectcampaignsv2>=1.36.0, <1.37.0",
            "mypy-boto3-connectcases>=1.36.0, <1.37.0",
            "mypy-boto3-connectparticipant>=1.36.0, <1.37.0",
            "mypy-boto3-controlcatalog>=1.36.0, <1.37.0",
            "mypy-boto3-controltower>=1.36.0, <1.37.0",
            "mypy-boto3-cost-optimization-hub>=1.36.0, <1.37.0",
            "mypy-boto3-cur>=1.36.0, <1.37.0",
            "mypy-boto3-customer-profiles>=1.36.0, <1.37.0",
            "mypy-boto3-databrew>=1.36.0, <1.37.0",
            "mypy-boto3-dataexchange>=1.36.0, <1.37.0",
            "mypy-boto3-datapipeline>=1.36.0, <1.37.0",
            "mypy-boto3-datasync>=1.36.0, <1.37.0",
            "mypy-boto3-datazone>=1.36.0, <1.37.0",
            "mypy-boto3-dax>=1.36.0, <1.37.0",
            "mypy-boto3-deadline>=1.36.0, <1.37.0",
            "mypy-boto3-detective>=1.36.0, <1.37.0",
            "mypy-boto3-devicefarm>=1.36.0, <1.37.0",
            "mypy-boto3-devops-guru>=1.36.0, <1.37.0",
            "mypy-boto3-directconnect>=1.36.0, <1.37.0",
            "mypy-boto3-discovery>=1.36.0, <1.37.0",
            "mypy-boto3-dlm>=1.36.0, <1.37.0",
            "mypy-boto3-dms>=1.36.0, <1.37.0",
            "mypy-boto3-docdb>=1.36.0, <1.37.0",
            "mypy-boto3-docdb-elastic>=1.36.0, <1.37.0",
            "mypy-boto3-drs>=1.36.0, <1.37.0",
            "mypy-boto3-ds>=1.36.0, <1.37.0",
            "mypy-boto3-ds-data>=1.36.0, <1.37.0",
            "mypy-boto3-dsql>=1.36.0, <1.37.0",
            "mypy-boto3-dynamodb>=1.36.0, <1.37.0",
            "mypy-boto3-dynamodbstreams>=1.36.0, <1.37.0",
            "mypy-boto3-ebs>=1.36.0, <1.37.0",
            "mypy-boto3-ec2>=1.36.0, <1.37.0",
            "mypy-boto3-ec2-instance-connect>=1.36.0, <1.37.0",
            "mypy-boto3-ecr>=1.36.0, <1.37.0",
            "mypy-boto3-ecr-public>=1.36.0, <1.37.0",
            "mypy-boto3-ecs>=1.36.0, <1.37.0",
            "mypy-boto3-efs>=1.36.0, <1.37.0",
            "mypy-boto3-eks>=1.36.0, <1.37.0",
            "mypy-boto3-eks-auth>=1.36.0, <1.37.0",
            "mypy-boto3-elastic-inference>=1.36.0, <1.37.0",
            "mypy-boto3-elasticache>=1.36.0, <1.37.0",
            "mypy-boto3-elasticbeanstalk>=1.36.0, <1.37.0",
            "mypy-boto3-elastictranscoder>=1.36.0, <1.37.0",
            "mypy-boto3-elb>=1.36.0, <1.37.0",
            "mypy-boto3-elbv2>=1.36.0, <1.37.0",
            "mypy-boto3-emr>=1.36.0, <1.37.0",
            "mypy-boto3-emr-containers>=1.36.0, <1.37.0",
            "mypy-boto3-emr-serverless>=1.36.0, <1.37.0",
            "mypy-boto3-entityresolution>=1.36.0, <1.37.0",
            "mypy-boto3-es>=1.36.0, <1.37.0",
            "mypy-boto3-events>=1.36.0, <1.37.0",
            "mypy-boto3-evidently>=1.36.0, <1.37.0",
            "mypy-boto3-finspace>=1.36.0, <1.37.0",
            "mypy-boto3-finspace-data>=1.36.0, <1.37.0",
            "mypy-boto3-firehose>=1.36.0, <1.37.0",
            "mypy-boto3-fis>=1.36.0, <1.37.0",
            "mypy-boto3-fms>=1.36.0, <1.37.0",
            "mypy-boto3-forecast>=1.36.0, <1.37.0",
            "mypy-boto3-forecastquery>=1.36.0, <1.37.0",
            "mypy-boto3-frauddetector>=1.36.0, <1.37.0",
            "mypy-boto3-freetier>=1.36.0, <1.37.0",
            "mypy-boto3-fsx>=1.36.0, <1.37.0",
            "mypy-boto3-gamelift>=1.36.0, <1.37.0",
            "mypy-boto3-geo-maps>=1.36.0, <1.37.0",
            "mypy-boto3-geo-places>=1.36.0, <1.37.0",
            "mypy-boto3-geo-routes>=1.36.0, <1.37.0",
            "mypy-boto3-glacier>=1.36.0, <1.37.0",
            "mypy-boto3-globalaccelerator>=1.36.0, <1.37.0",
            "mypy-boto3-glue>=1.36.0, <1.37.0",
            "mypy-boto3-grafana>=1.36.0, <1.37.0",
            "mypy-boto3-greengrass>=1.36.0, <1.37.0",
            "mypy-boto3-greengrassv2>=1.36.0, <1.37.0",
            "mypy-boto3-groundstation>=1.36.0, <1.37.0",
            "mypy-boto3-guardduty>=1.36.0, <1.37.0",
            "mypy-boto3-health>=1.36.0, <1.37.0",
            "mypy-boto3-healthlake>=1.36.0, <1.37.0",
            "mypy-boto3-iam>=1.36.0, <1.37.0",
            "mypy-boto3-identitystore>=1.36.0, <1.37.0",
            "mypy-boto3-imagebuilder>=1.36.0, <1.37.0",
            "mypy-boto3-importexport>=1.36.0, <1.37.0",
            "mypy-boto3-inspector>=1.36.0, <1.37.0",
            "mypy-boto3-inspector-scan>=1.36.0, <1.37.0",
            "mypy-boto3-inspector2>=1.36.0, <1.37.0",
            "mypy-boto3-internetmonitor>=1.36.0, <1.37.0",
            "mypy-boto3-invoicing>=1.36.0, <1.37.0",
            "mypy-boto3-iot>=1.36.0, <1.37.0",
            "mypy-boto3-iot-data>=1.36.0, <1.37.0",
            "mypy-boto3-iot-jobs-data>=1.36.0, <1.37.0",
            "mypy-boto3-iotanalytics>=1.36.0, <1.37.0",
            "mypy-boto3-iotdeviceadvisor>=1.36.0, <1.37.0",
            "mypy-boto3-iotevents>=1.36.0, <1.37.0",
            "mypy-boto3-iotevents-data>=1.36.0, <1.37.0",
            "mypy-boto3-iotfleethub>=1.36.0, <1.37.0",
            "mypy-boto3-iotfleetwise>=1.36.0, <1.37.0",
            "mypy-boto3-iotsecuretunneling>=1.36.0, <1.37.0",
            "mypy-boto3-iotsitewise>=1.36.0, <1.37.0",
            "mypy-boto3-iotthingsgraph>=1.36.0, <1.37.0",
            "mypy-boto3-iottwinmaker>=1.36.0, <1.37.0",
            "mypy-boto3-iotwireless>=1.36.0, <1.37.0",
            "mypy-boto3-ivs>=1.36.0, <1.37.0",
            "mypy-boto3-ivs-realtime>=1.36.0, <1.37.0",
            "mypy-boto3-ivschat>=1.36.0, <1.37.0",
            "mypy-boto3-kafka>=1.36.0, <1.37.0",
            "mypy-boto3-kafkaconnect>=1.36.0, <1.37.0",
            "mypy-boto3-kendra>=1.36.0, <1.37.0",
            "mypy-boto3-kendra-ranking>=1.36.0, <1.37.0",
            "mypy-boto3-keyspaces>=1.36.0, <1.37.0",
            "mypy-boto3-kinesis>=1.36.0, <1.37.0",
            "mypy-boto3-kinesis-video-archived-media>=1.36.0, <1.37.0",
            "mypy-boto3-kinesis-video-media>=1.36.0, <1.37.0",
            "mypy-boto3-kinesis-video-signaling>=1.36.0, <1.37.0",
            "mypy-boto3-kinesis-video-webrtc-storage>=1.36.0, <1.37.0",
            "mypy-boto3-kinesisanalytics>=1.36.0, <1.37.0",
            "mypy-boto3-kinesisanalyticsv2>=1.36.0, <1.37.0",
            "mypy-boto3-kinesisvideo>=1.36.0, <1.37.0",
            "mypy-boto3-kms>=1.36.0, <1.37.0",
            "mypy-boto3-lakeformation>=1.36.0, <1.37.0",
            "mypy-boto3-lambda>=1.36.0, <1.37.0",
            "mypy-boto3-launch-wizard>=1.36.0, <1.37.0",
            "mypy-boto3-lex-models>=1.36.0, <1.37.0",
            "mypy-boto3-lex-runtime>=1.36.0, <1.37.0",
            "mypy-boto3-lexv2-models>=1.36.0, <1.37.0",
            "mypy-boto3-lexv2-runtime>=1.36.0, <1.37.0",
            "mypy-boto3-license-manager>=1.36.0, <1.37.0",
            "mypy-boto3-license-manager-linux-subscriptions>=1.36.0, <1.37.0",
            "mypy-boto3-license-manager-user-subscriptions>=1.36.0, <1.37.0",
            "mypy-boto3-lightsail>=1.36.0, <1.37.0",
            "mypy-boto3-location>=1.36.0, <1.37.0",
            "mypy-boto3-logs>=1.36.0, <1.37.0",
            "mypy-boto3-lookoutequipment>=1.36.0, <1.37.0",
            "mypy-boto3-lookoutmetrics>=1.36.0, <1.37.0",
            "mypy-boto3-lookoutvision>=1.36.0, <1.37.0",
            "mypy-boto3-m2>=1.36.0, <1.37.0",
            "mypy-boto3-machinelearning>=1.36.0, <1.37.0",
            "mypy-boto3-macie2>=1.36.0, <1.37.0",
            "mypy-boto3-mailmanager>=1.36.0, <1.37.0",
            "mypy-boto3-managedblockchain>=1.36.0, <1.37.0",
            "mypy-boto3-managedblockchain-query>=1.36.0, <1.37.0",
            "mypy-boto3-marketplace-agreement>=1.36.0, <1.37.0",
            "mypy-boto3-marketplace-catalog>=1.36.0, <1.37.0",
            "mypy-boto3-marketplace-deployment>=1.36.0, <1.37.0",
            "mypy-boto3-marketplace-entitlement>=1.36.0, <1.37.0",
            "mypy-boto3-marketplace-reporting>=1.36.0, <1.37.0",
            "mypy-boto3-marketplacecommerceanalytics>=1.36.0, <1.37.0",
            "mypy-boto3-mediaconnect>=1.36.0, <1.37.0",
            "mypy-boto3-mediaconvert>=1.36.0, <1.37.0",
            "mypy-boto3-medialive>=1.36.0, <1.37.0",
            "mypy-boto3-mediapackage>=1.36.0, <1.37.0",
            "mypy-boto3-mediapackage-vod>=1.36.0, <1.37.0",
            "mypy-boto3-mediapackagev2>=1.36.0, <1.37.0",
            "mypy-boto3-mediastore>=1.36.0, <1.37.0",
            "mypy-boto3-mediastore-data>=1.36.0, <1.37.0",
            "mypy-boto3-mediatailor>=1.36.0, <1.37.0",
            "mypy-boto3-medical-imaging>=1.36.0, <1.37.0",
            "mypy-boto3-memorydb>=1.36.0, <1.37.0",
            "mypy-boto3-meteringmarketplace>=1.36.0, <1.37.0",
            "mypy-boto3-mgh>=1.36.0, <1.37.0",
            "mypy-boto3-mgn>=1.36.0, <1.37.0",
            "mypy-boto3-migration-hub-refactor-spaces>=1.36.0, <1.37.0",
            "mypy-boto3-migrationhub-config>=1.36.0, <1.37.0",
            "mypy-boto3-migrationhuborchestrator>=1.36.0, <1.37.0",
            "mypy-boto3-migrationhubstrategy>=1.36.0, <1.37.0",
            "mypy-boto3-mq>=1.36.0, <1.37.0",
            "mypy-boto3-mturk>=1.36.0, <1.37.0",
            "mypy-boto3-mwaa>=1.36.0, <1.37.0",
            "mypy-boto3-neptune>=1.36.0, <1.37.0",
            "mypy-boto3-neptune-graph>=1.36.0, <1.37.0",
            "mypy-boto3-neptunedata>=1.36.0, <1.37.0",
            "mypy-boto3-network-firewall>=1.36.0, <1.37.0",
            "mypy-boto3-networkflowmonitor>=1.36.0, <1.37.0",
            "mypy-boto3-networkmanager>=1.36.0, <1.37.0",
            "mypy-boto3-networkmonitor>=1.36.0, <1.37.0",
            "mypy-boto3-notifications>=1.36.0, <1.37.0",
            "mypy-boto3-notificationscontacts>=1.36.0, <1.37.0",
            "mypy-boto3-oam>=1.36.0, <1.37.0",
            "mypy-boto3-observabilityadmin>=1.36.0, <1.37.0",
            "mypy-boto3-omics>=1.36.0, <1.37.0",
            "mypy-boto3-opensearch>=1.36.0, <1.37.0",
            "mypy-boto3-opensearchserverless>=1.36.0, <1.37.0",
            "mypy-boto3-opsworks>=1.36.0, <1.37.0",
            "mypy-boto3-opsworkscm>=1.36.0, <1.37.0",
            "mypy-boto3-organizations>=1.36.0, <1.37.0",
            "mypy-boto3-osis>=1.36.0, <1.37.0",
            "mypy-boto3-outposts>=1.36.0, <1.37.0",
            "mypy-boto3-panorama>=1.36.0, <1.37.0",
            "mypy-boto3-partnercentral-selling>=1.36.0, <1.37.0",
            "mypy-boto3-payment-cryptography>=1.36.0, <1.37.0",
            "mypy-boto3-payment-cryptography-data>=1.36.0, <1.37.0",
            "mypy-boto3-pca-connector-ad>=1.36.0, <1.37.0",
            "mypy-boto3-pca-connector-scep>=1.36.0, <1.37.0",
            "mypy-boto3-pcs>=1.36.0, <1.37.0",
            "mypy-boto3-personalize>=1.36.0, <1.37.0",
            "mypy-boto3-personalize-events>=1.36.0, <1.37.0",
            "mypy-boto3-personalize-runtime>=1.36.0, <1.37.0",
            "mypy-boto3-pi>=1.36.0, <1.37.0",
            "mypy-boto3-pinpoint>=1.36.0, <1.37.0",
            "mypy-boto3-pinpoint-email>=1.36.0, <1.37.0",
            "mypy-boto3-pinpoint-sms-voice>=1.36.0, <1.37.0",
            "mypy-boto3-pinpoint-sms-voice-v2>=1.36.0, <1.37.0",
            "mypy-boto3-pipes>=1.36.0, <1.37.0",
            "mypy-boto3-polly>=1.36.0, <1.37.0",
            "mypy-boto3-pricing>=1.36.0, <1.37.0",
            "mypy-boto3-privatenetworks>=1.36.0, <1.37.0",
            "mypy-boto3-proton>=1.36.0, <1.37.0",
            "mypy-boto3-qapps>=1.36.0, <1.37.0",
            "mypy-boto3-qbusiness>=1.36.0, <1.37.0",
            "mypy-boto3-qconnect>=1.36.0, <1.37.0",
            "mypy-boto3-qldb>=1.36.0, <1.37.0",
            "mypy-boto3-qldb-session>=1.36.0, <1.37.0",
            "mypy-boto3-quicksight>=1.36.0, <1.37.0",
            "mypy-boto3-ram>=1.36.0, <1.37.0",
            "mypy-boto3-rbin>=1.36.0, <1.37.0",
            "mypy-boto3-rds>=1.36.0, <1.37.0",
            "mypy-boto3-rds-data>=1.36.0, <1.37.0",
            "mypy-boto3-redshift>=1.36.0, <1.37.0",
            "mypy-boto3-redshift-data>=1.36.0, <1.37.0",
            "mypy-boto3-redshift-serverless>=1.36.0, <1.37.0",
            "mypy-boto3-rekognition>=1.36.0, <1.37.0",
            "mypy-boto3-repostspace>=1.36.0, <1.37.0",
            "mypy-boto3-resiliencehub>=1.36.0, <1.37.0",
            "mypy-boto3-resource-explorer-2>=1.36.0, <1.37.0",
            "mypy-boto3-resource-groups>=1.36.0, <1.37.0",
            "mypy-boto3-resourcegroupstaggingapi>=1.36.0, <1.37.0",
            "mypy-boto3-robomaker>=1.36.0, <1.37.0",
            "mypy-boto3-rolesanywhere>=1.36.0, <1.37.0",
            "mypy-boto3-route53>=1.36.0, <1.37.0",
            "mypy-boto3-route53-recovery-cluster>=1.36.0, <1.37.0",
            "mypy-boto3-route53-recovery-control-config>=1.36.0, <1.37.0",
            "mypy-boto3-route53-recovery-readiness>=1.36.0, <1.37.0",
            "mypy-boto3-route53domains>=1.36.0, <1.37.0",
            "mypy-boto3-route53profiles>=1.36.0, <1.37.0",
            "mypy-boto3-route53resolver>=1.36.0, <1.37.0",
            "mypy-boto3-rum>=1.36.0, <1.37.0",
            "mypy-boto3-s3>=1.36.0, <1.37.0",
            "mypy-boto3-s3control>=1.36.0, <1.37.0",
            "mypy-boto3-s3outposts>=1.36.0, <1.37.0",
            "mypy-boto3-s3tables>=1.36.0, <1.37.0",
            "mypy-boto3-sagemaker>=1.36.0, <1.37.0",
            "mypy-boto3-sagemaker-a2i-runtime>=1.36.0, <1.37.0",
            "mypy-boto3-sagemaker-edge>=1.36.0, <1.37.0",
            "mypy-boto3-sagemaker-featurestore-runtime>=1.36.0, <1.37.0",
            "mypy-boto3-sagemaker-geospatial>=1.36.0, <1.37.0",
            "mypy-boto3-sagemaker-metrics>=1.36.0, <1.37.0",
            "mypy-boto3-sagemaker-runtime>=1.36.0, <1.37.0",
            "mypy-boto3-savingsplans>=1.36.0, <1.37.0",
            "mypy-boto3-scheduler>=1.36.0, <1.37.0",
            "mypy-boto3-schemas>=1.36.0, <1.37.0",
            "mypy-boto3-sdb>=1.36.0, <1.37.0",
            "mypy-boto3-secretsmanager>=1.36.0, <1.37.0",
            "mypy-boto3-security-ir>=1.36.0, <1.37.0",
            "mypy-boto3-securityhub>=1.36.0, <1.37.0",
            "mypy-boto3-securitylake>=1.36.0, <1.37.0",
            "mypy-boto3-serverlessrepo>=1.36.0, <1.37.0",
            "mypy-boto3-service-quotas>=1.36.0, <1.37.0",
            "mypy-boto3-servicecatalog>=1.36.0, <1.37.0",
            "mypy-boto3-servicecatalog-appregistry>=1.36.0, <1.37.0",
            "mypy-boto3-servicediscovery>=1.36.0, <1.37.0",
            "mypy-boto3-ses>=1.36.0, <1.37.0",
            "mypy-boto3-sesv2>=1.36.0, <1.37.0",
            "mypy-boto3-shield>=1.36.0, <1.37.0",
            "mypy-boto3-signer>=1.36.0, <1.37.0",
            "mypy-boto3-simspaceweaver>=1.36.0, <1.37.0",
            "mypy-boto3-sms>=1.36.0, <1.37.0",
            "mypy-boto3-sms-voice>=1.36.0, <1.37.0",
            "mypy-boto3-snow-device-management>=1.36.0, <1.37.0",
            "mypy-boto3-snowball>=1.36.0, <1.37.0",
            "mypy-boto3-sns>=1.36.0, <1.37.0",
            "mypy-boto3-socialmessaging>=1.36.0, <1.37.0",
            "mypy-boto3-sqs>=1.36.0, <1.37.0",
            "mypy-boto3-ssm>=1.36.0, <1.37.0",
            "mypy-boto3-ssm-contacts>=1.36.0, <1.37.0",
            "mypy-boto3-ssm-incidents>=1.36.0, <1.37.0",
            "mypy-boto3-ssm-quicksetup>=1.36.0, <1.37.0",
            "mypy-boto3-ssm-sap>=1.36.0, <1.37.0",
            "mypy-boto3-sso>=1.36.0, <1.37.0",
            "mypy-boto3-sso-admin>=1.36.0, <1.37.0",
            "mypy-boto3-sso-oidc>=1.36.0, <1.37.0",
            "mypy-boto3-stepfunctions>=1.36.0, <1.37.0",
            "mypy-boto3-storagegateway>=1.36.0, <1.37.0",
            "mypy-boto3-sts>=1.36.0, <1.37.0",
            "mypy-boto3-supplychain>=1.36.0, <1.37.0",
            "mypy-boto3-support>=1.36.0, <1.37.0",
            "mypy-boto3-support-app>=1.36.0, <1.37.0",
            "mypy-boto3-swf>=1.36.0, <1.37.0",
            "mypy-boto3-synthetics>=1.36.0, <1.37.0",
            "mypy-boto3-taxsettings>=1.36.0, <1.37.0",
            "mypy-boto3-textract>=1.36.0, <1.37.0",
            "mypy-boto3-timestream-influxdb>=1.36.0, <1.37.0",
            "mypy-boto3-timestream-query>=1.36.0, <1.37.0",
            "mypy-boto3-timestream-write>=1.36.0, <1.37.0",
            "mypy-boto3-tnb>=1.36.0, <1.37.0",
            "mypy-boto3-transcribe>=1.36.0, <1.37.0",
            "mypy-boto3-transfer>=1.36.0, <1.37.0",
            "mypy-boto3-translate>=1.36.0, <1.37.0",
            "mypy-boto3-trustedadvisor>=1.36.0, <1.37.0",
            "mypy-boto3-verifiedpermissions>=1.36.0, <1.37.0",
            "mypy-boto3-voice-id>=1.36.0, <1.37.0",
            "mypy-boto3-vpc-lattice>=1.36.0, <1.37.0",
            "mypy-boto3-waf>=1.36.0, <1.37.0",
            "mypy-boto3-waf-regional>=1.36.0, <1.37.0",
            "mypy-boto3-wafv2>=1.36.0, <1.37.0",
            "mypy-boto3-wellarchitected>=1.36.0, <1.37.0",
            "mypy-boto3-wisdom>=1.36.0, <1.37.0",
            "mypy-boto3-workdocs>=1.36.0, <1.37.0",
            "mypy-boto3-workmail>=1.36.0, <1.37.0",
            "mypy-boto3-workmailmessageflow>=1.36.0, <1.37.0",
            "mypy-boto3-workspaces>=1.36.0, <1.37.0",
            "mypy-boto3-workspaces-thin-client>=1.36.0, <1.37.0",
            "mypy-boto3-workspaces-web>=1.36.0, <1.37.0",
            "mypy-boto3-xray>=1.36.0, <1.37.0",
        ],
        "essential": [
            "mypy-boto3-cloudformation>=1.36.0, <1.37.0",
            "mypy-boto3-dynamodb>=1.36.0, <1.37.0",
            "mypy-boto3-ec2>=1.36.0, <1.37.0",
            "mypy-boto3-lambda>=1.36.0, <1.37.0",
            "mypy-boto3-rds>=1.36.0, <1.37.0",
            "mypy-boto3-s3>=1.36.0, <1.37.0",
            "mypy-boto3-sqs>=1.36.0, <1.37.0",
        ],
        "accessanalyzer": ["mypy-boto3-accessanalyzer>=1.36.0, <1.37.0"],
        "account": ["mypy-boto3-account>=1.36.0, <1.37.0"],
        "acm": ["mypy-boto3-acm>=1.36.0, <1.37.0"],
        "acm-pca": ["mypy-boto3-acm-pca>=1.36.0, <1.37.0"],
        "amp": ["mypy-boto3-amp>=1.36.0, <1.37.0"],
        "amplify": ["mypy-boto3-amplify>=1.36.0, <1.37.0"],
        "amplifybackend": ["mypy-boto3-amplifybackend>=1.36.0, <1.37.0"],
        "amplifyuibuilder": ["mypy-boto3-amplifyuibuilder>=1.36.0, <1.37.0"],
        "apigateway": ["mypy-boto3-apigateway>=1.36.0, <1.37.0"],
        "apigatewaymanagementapi": ["mypy-boto3-apigatewaymanagementapi>=1.36.0, <1.37.0"],
        "apigatewayv2": ["mypy-boto3-apigatewayv2>=1.36.0, <1.37.0"],
        "appconfig": ["mypy-boto3-appconfig>=1.36.0, <1.37.0"],
        "appconfigdata": ["mypy-boto3-appconfigdata>=1.36.0, <1.37.0"],
        "appfabric": ["mypy-boto3-appfabric>=1.36.0, <1.37.0"],
        "appflow": ["mypy-boto3-appflow>=1.36.0, <1.37.0"],
        "appintegrations": ["mypy-boto3-appintegrations>=1.36.0, <1.37.0"],
        "application-autoscaling": ["mypy-boto3-application-autoscaling>=1.36.0, <1.37.0"],
        "application-insights": ["mypy-boto3-application-insights>=1.36.0, <1.37.0"],
        "application-signals": ["mypy-boto3-application-signals>=1.36.0, <1.37.0"],
        "applicationcostprofiler": ["mypy-boto3-applicationcostprofiler>=1.36.0, <1.37.0"],
        "appmesh": ["mypy-boto3-appmesh>=1.36.0, <1.37.0"],
        "apprunner": ["mypy-boto3-apprunner>=1.36.0, <1.37.0"],
        "appstream": ["mypy-boto3-appstream>=1.36.0, <1.37.0"],
        "appsync": ["mypy-boto3-appsync>=1.36.0, <1.37.0"],
        "apptest": ["mypy-boto3-apptest>=1.36.0, <1.37.0"],
        "arc-zonal-shift": ["mypy-boto3-arc-zonal-shift>=1.36.0, <1.37.0"],
        "artifact": ["mypy-boto3-artifact>=1.36.0, <1.37.0"],
        "athena": ["mypy-boto3-athena>=1.36.0, <1.37.0"],
        "auditmanager": ["mypy-boto3-auditmanager>=1.36.0, <1.37.0"],
        "autoscaling": ["mypy-boto3-autoscaling>=1.36.0, <1.37.0"],
        "autoscaling-plans": ["mypy-boto3-autoscaling-plans>=1.36.0, <1.37.0"],
        "b2bi": ["mypy-boto3-b2bi>=1.36.0, <1.37.0"],
        "backup": ["mypy-boto3-backup>=1.36.0, <1.37.0"],
        "backup-gateway": ["mypy-boto3-backup-gateway>=1.36.0, <1.37.0"],
        "backupsearch": ["mypy-boto3-backupsearch>=1.36.0, <1.37.0"],
        "batch": ["mypy-boto3-batch>=1.36.0, <1.37.0"],
        "bcm-data-exports": ["mypy-boto3-bcm-data-exports>=1.36.0, <1.37.0"],
        "bcm-pricing-calculator": ["mypy-boto3-bcm-pricing-calculator>=1.36.0, <1.37.0"],
        "bedrock": ["mypy-boto3-bedrock>=1.36.0, <1.37.0"],
        "bedrock-agent": ["mypy-boto3-bedrock-agent>=1.36.0, <1.37.0"],
        "bedrock-agent-runtime": ["mypy-boto3-bedrock-agent-runtime>=1.36.0, <1.37.0"],
        "bedrock-data-automation": ["mypy-boto3-bedrock-data-automation>=1.36.0, <1.37.0"],
        "bedrock-data-automation-runtime": [
            "mypy-boto3-bedrock-data-automation-runtime>=1.36.0, <1.37.0"
        ],
        "bedrock-runtime": ["mypy-boto3-bedrock-runtime>=1.36.0, <1.37.0"],
        "billing": ["mypy-boto3-billing>=1.36.0, <1.37.0"],
        "billingconductor": ["mypy-boto3-billingconductor>=1.36.0, <1.37.0"],
        "braket": ["mypy-boto3-braket>=1.36.0, <1.37.0"],
        "budgets": ["mypy-boto3-budgets>=1.36.0, <1.37.0"],
        "ce": ["mypy-boto3-ce>=1.36.0, <1.37.0"],
        "chatbot": ["mypy-boto3-chatbot>=1.36.0, <1.37.0"],
        "chime": ["mypy-boto3-chime>=1.36.0, <1.37.0"],
        "chime-sdk-identity": ["mypy-boto3-chime-sdk-identity>=1.36.0, <1.37.0"],
        "chime-sdk-media-pipelines": ["mypy-boto3-chime-sdk-media-pipelines>=1.36.0, <1.37.0"],
        "chime-sdk-meetings": ["mypy-boto3-chime-sdk-meetings>=1.36.0, <1.37.0"],
        "chime-sdk-messaging": ["mypy-boto3-chime-sdk-messaging>=1.36.0, <1.37.0"],
        "chime-sdk-voice": ["mypy-boto3-chime-sdk-voice>=1.36.0, <1.37.0"],
        "cleanrooms": ["mypy-boto3-cleanrooms>=1.36.0, <1.37.0"],
        "cleanroomsml": ["mypy-boto3-cleanroomsml>=1.36.0, <1.37.0"],
        "cloud9": ["mypy-boto3-cloud9>=1.36.0, <1.37.0"],
        "cloudcontrol": ["mypy-boto3-cloudcontrol>=1.36.0, <1.37.0"],
        "clouddirectory": ["mypy-boto3-clouddirectory>=1.36.0, <1.37.0"],
        "cloudformation": ["mypy-boto3-cloudformation>=1.36.0, <1.37.0"],
        "cloudfront": ["mypy-boto3-cloudfront>=1.36.0, <1.37.0"],
        "cloudfront-keyvaluestore": ["mypy-boto3-cloudfront-keyvaluestore>=1.36.0, <1.37.0"],
        "cloudhsm": ["mypy-boto3-cloudhsm>=1.36.0, <1.37.0"],
        "cloudhsmv2": ["mypy-boto3-cloudhsmv2>=1.36.0, <1.37.0"],
        "cloudsearch": ["mypy-boto3-cloudsearch>=1.36.0, <1.37.0"],
        "cloudsearchdomain": ["mypy-boto3-cloudsearchdomain>=1.36.0, <1.37.0"],
        "cloudtrail": ["mypy-boto3-cloudtrail>=1.36.0, <1.37.0"],
        "cloudtrail-data": ["mypy-boto3-cloudtrail-data>=1.36.0, <1.37.0"],
        "cloudwatch": ["mypy-boto3-cloudwatch>=1.36.0, <1.37.0"],
        "codeartifact": ["mypy-boto3-codeartifact>=1.36.0, <1.37.0"],
        "codebuild": ["mypy-boto3-codebuild>=1.36.0, <1.37.0"],
        "codecatalyst": ["mypy-boto3-codecatalyst>=1.36.0, <1.37.0"],
        "codecommit": ["mypy-boto3-codecommit>=1.36.0, <1.37.0"],
        "codeconnections": ["mypy-boto3-codeconnections>=1.36.0, <1.37.0"],
        "codedeploy": ["mypy-boto3-codedeploy>=1.36.0, <1.37.0"],
        "codeguru-reviewer": ["mypy-boto3-codeguru-reviewer>=1.36.0, <1.37.0"],
        "codeguru-security": ["mypy-boto3-codeguru-security>=1.36.0, <1.37.0"],
        "codeguruprofiler": ["mypy-boto3-codeguruprofiler>=1.36.0, <1.37.0"],
        "codepipeline": ["mypy-boto3-codepipeline>=1.36.0, <1.37.0"],
        "codestar-connections": ["mypy-boto3-codestar-connections>=1.36.0, <1.37.0"],
        "codestar-notifications": ["mypy-boto3-codestar-notifications>=1.36.0, <1.37.0"],
        "cognito-identity": ["mypy-boto3-cognito-identity>=1.36.0, <1.37.0"],
        "cognito-idp": ["mypy-boto3-cognito-idp>=1.36.0, <1.37.0"],
        "cognito-sync": ["mypy-boto3-cognito-sync>=1.36.0, <1.37.0"],
        "comprehend": ["mypy-boto3-comprehend>=1.36.0, <1.37.0"],
        "comprehendmedical": ["mypy-boto3-comprehendmedical>=1.36.0, <1.37.0"],
        "compute-optimizer": ["mypy-boto3-compute-optimizer>=1.36.0, <1.37.0"],
        "config": ["mypy-boto3-config>=1.36.0, <1.37.0"],
        "connect": ["mypy-boto3-connect>=1.36.0, <1.37.0"],
        "connect-contact-lens": ["mypy-boto3-connect-contact-lens>=1.36.0, <1.37.0"],
        "connectcampaigns": ["mypy-boto3-connectcampaigns>=1.36.0, <1.37.0"],
        "connectcampaignsv2": ["mypy-boto3-connectcampaignsv2>=1.36.0, <1.37.0"],
        "connectcases": ["mypy-boto3-connectcases>=1.36.0, <1.37.0"],
        "connectparticipant": ["mypy-boto3-connectparticipant>=1.36.0, <1.37.0"],
        "controlcatalog": ["mypy-boto3-controlcatalog>=1.36.0, <1.37.0"],
        "controltower": ["mypy-boto3-controltower>=1.36.0, <1.37.0"],
        "cost-optimization-hub": ["mypy-boto3-cost-optimization-hub>=1.36.0, <1.37.0"],
        "cur": ["mypy-boto3-cur>=1.36.0, <1.37.0"],
        "customer-profiles": ["mypy-boto3-customer-profiles>=1.36.0, <1.37.0"],
        "databrew": ["mypy-boto3-databrew>=1.36.0, <1.37.0"],
        "dataexchange": ["mypy-boto3-dataexchange>=1.36.0, <1.37.0"],
        "datapipeline": ["mypy-boto3-datapipeline>=1.36.0, <1.37.0"],
        "datasync": ["mypy-boto3-datasync>=1.36.0, <1.37.0"],
        "datazone": ["mypy-boto3-datazone>=1.36.0, <1.37.0"],
        "dax": ["mypy-boto3-dax>=1.36.0, <1.37.0"],
        "deadline": ["mypy-boto3-deadline>=1.36.0, <1.37.0"],
        "detective": ["mypy-boto3-detective>=1.36.0, <1.37.0"],
        "devicefarm": ["mypy-boto3-devicefarm>=1.36.0, <1.37.0"],
        "devops-guru": ["mypy-boto3-devops-guru>=1.36.0, <1.37.0"],
        "directconnect": ["mypy-boto3-directconnect>=1.36.0, <1.37.0"],
        "discovery": ["mypy-boto3-discovery>=1.36.0, <1.37.0"],
        "dlm": ["mypy-boto3-dlm>=1.36.0, <1.37.0"],
        "dms": ["mypy-boto3-dms>=1.36.0, <1.37.0"],
        "docdb": ["mypy-boto3-docdb>=1.36.0, <1.37.0"],
        "docdb-elastic": ["mypy-boto3-docdb-elastic>=1.36.0, <1.37.0"],
        "drs": ["mypy-boto3-drs>=1.36.0, <1.37.0"],
        "ds": ["mypy-boto3-ds>=1.36.0, <1.37.0"],
        "ds-data": ["mypy-boto3-ds-data>=1.36.0, <1.37.0"],
        "dsql": ["mypy-boto3-dsql>=1.36.0, <1.37.0"],
        "dynamodb": ["mypy-boto3-dynamodb>=1.36.0, <1.37.0"],
        "dynamodbstreams": ["mypy-boto3-dynamodbstreams>=1.36.0, <1.37.0"],
        "ebs": ["mypy-boto3-ebs>=1.36.0, <1.37.0"],
        "ec2": ["mypy-boto3-ec2>=1.36.0, <1.37.0"],
        "ec2-instance-connect": ["mypy-boto3-ec2-instance-connect>=1.36.0, <1.37.0"],
        "ecr": ["mypy-boto3-ecr>=1.36.0, <1.37.0"],
        "ecr-public": ["mypy-boto3-ecr-public>=1.36.0, <1.37.0"],
        "ecs": ["mypy-boto3-ecs>=1.36.0, <1.37.0"],
        "efs": ["mypy-boto3-efs>=1.36.0, <1.37.0"],
        "eks": ["mypy-boto3-eks>=1.36.0, <1.37.0"],
        "eks-auth": ["mypy-boto3-eks-auth>=1.36.0, <1.37.0"],
        "elastic-inference": ["mypy-boto3-elastic-inference>=1.36.0, <1.37.0"],
        "elasticache": ["mypy-boto3-elasticache>=1.36.0, <1.37.0"],
        "elasticbeanstalk": ["mypy-boto3-elasticbeanstalk>=1.36.0, <1.37.0"],
        "elastictranscoder": ["mypy-boto3-elastictranscoder>=1.36.0, <1.37.0"],
        "elb": ["mypy-boto3-elb>=1.36.0, <1.37.0"],
        "elbv2": ["mypy-boto3-elbv2>=1.36.0, <1.37.0"],
        "emr": ["mypy-boto3-emr>=1.36.0, <1.37.0"],
        "emr-containers": ["mypy-boto3-emr-containers>=1.36.0, <1.37.0"],
        "emr-serverless": ["mypy-boto3-emr-serverless>=1.36.0, <1.37.0"],
        "entityresolution": ["mypy-boto3-entityresolution>=1.36.0, <1.37.0"],
        "es": ["mypy-boto3-es>=1.36.0, <1.37.0"],
        "events": ["mypy-boto3-events>=1.36.0, <1.37.0"],
        "evidently": ["mypy-boto3-evidently>=1.36.0, <1.37.0"],
        "finspace": ["mypy-boto3-finspace>=1.36.0, <1.37.0"],
        "finspace-data": ["mypy-boto3-finspace-data>=1.36.0, <1.37.0"],
        "firehose": ["mypy-boto3-firehose>=1.36.0, <1.37.0"],
        "fis": ["mypy-boto3-fis>=1.36.0, <1.37.0"],
        "fms": ["mypy-boto3-fms>=1.36.0, <1.37.0"],
        "forecast": ["mypy-boto3-forecast>=1.36.0, <1.37.0"],
        "forecastquery": ["mypy-boto3-forecastquery>=1.36.0, <1.37.0"],
        "frauddetector": ["mypy-boto3-frauddetector>=1.36.0, <1.37.0"],
        "freetier": ["mypy-boto3-freetier>=1.36.0, <1.37.0"],
        "fsx": ["mypy-boto3-fsx>=1.36.0, <1.37.0"],
        "gamelift": ["mypy-boto3-gamelift>=1.36.0, <1.37.0"],
        "geo-maps": ["mypy-boto3-geo-maps>=1.36.0, <1.37.0"],
        "geo-places": ["mypy-boto3-geo-places>=1.36.0, <1.37.0"],
        "geo-routes": ["mypy-boto3-geo-routes>=1.36.0, <1.37.0"],
        "glacier": ["mypy-boto3-glacier>=1.36.0, <1.37.0"],
        "globalaccelerator": ["mypy-boto3-globalaccelerator>=1.36.0, <1.37.0"],
        "glue": ["mypy-boto3-glue>=1.36.0, <1.37.0"],
        "grafana": ["mypy-boto3-grafana>=1.36.0, <1.37.0"],
        "greengrass": ["mypy-boto3-greengrass>=1.36.0, <1.37.0"],
        "greengrassv2": ["mypy-boto3-greengrassv2>=1.36.0, <1.37.0"],
        "groundstation": ["mypy-boto3-groundstation>=1.36.0, <1.37.0"],
        "guardduty": ["mypy-boto3-guardduty>=1.36.0, <1.37.0"],
        "health": ["mypy-boto3-health>=1.36.0, <1.37.0"],
        "healthlake": ["mypy-boto3-healthlake>=1.36.0, <1.37.0"],
        "iam": ["mypy-boto3-iam>=1.36.0, <1.37.0"],
        "identitystore": ["mypy-boto3-identitystore>=1.36.0, <1.37.0"],
        "imagebuilder": ["mypy-boto3-imagebuilder>=1.36.0, <1.37.0"],
        "importexport": ["mypy-boto3-importexport>=1.36.0, <1.37.0"],
        "inspector": ["mypy-boto3-inspector>=1.36.0, <1.37.0"],
        "inspector-scan": ["mypy-boto3-inspector-scan>=1.36.0, <1.37.0"],
        "inspector2": ["mypy-boto3-inspector2>=1.36.0, <1.37.0"],
        "internetmonitor": ["mypy-boto3-internetmonitor>=1.36.0, <1.37.0"],
        "invoicing": ["mypy-boto3-invoicing>=1.36.0, <1.37.0"],
        "iot": ["mypy-boto3-iot>=1.36.0, <1.37.0"],
        "iot-data": ["mypy-boto3-iot-data>=1.36.0, <1.37.0"],
        "iot-jobs-data": ["mypy-boto3-iot-jobs-data>=1.36.0, <1.37.0"],
        "iotanalytics": ["mypy-boto3-iotanalytics>=1.36.0, <1.37.0"],
        "iotdeviceadvisor": ["mypy-boto3-iotdeviceadvisor>=1.36.0, <1.37.0"],
        "iotevents": ["mypy-boto3-iotevents>=1.36.0, <1.37.0"],
        "iotevents-data": ["mypy-boto3-iotevents-data>=1.36.0, <1.37.0"],
        "iotfleethub": ["mypy-boto3-iotfleethub>=1.36.0, <1.37.0"],
        "iotfleetwise": ["mypy-boto3-iotfleetwise>=1.36.0, <1.37.0"],
        "iotsecuretunneling": ["mypy-boto3-iotsecuretunneling>=1.36.0, <1.37.0"],
        "iotsitewise": ["mypy-boto3-iotsitewise>=1.36.0, <1.37.0"],
        "iotthingsgraph": ["mypy-boto3-iotthingsgraph>=1.36.0, <1.37.0"],
        "iottwinmaker": ["mypy-boto3-iottwinmaker>=1.36.0, <1.37.0"],
        "iotwireless": ["mypy-boto3-iotwireless>=1.36.0, <1.37.0"],
        "ivs": ["mypy-boto3-ivs>=1.36.0, <1.37.0"],
        "ivs-realtime": ["mypy-boto3-ivs-realtime>=1.36.0, <1.37.0"],
        "ivschat": ["mypy-boto3-ivschat>=1.36.0, <1.37.0"],
        "kafka": ["mypy-boto3-kafka>=1.36.0, <1.37.0"],
        "kafkaconnect": ["mypy-boto3-kafkaconnect>=1.36.0, <1.37.0"],
        "kendra": ["mypy-boto3-kendra>=1.36.0, <1.37.0"],
        "kendra-ranking": ["mypy-boto3-kendra-ranking>=1.36.0, <1.37.0"],
        "keyspaces": ["mypy-boto3-keyspaces>=1.36.0, <1.37.0"],
        "kinesis": ["mypy-boto3-kinesis>=1.36.0, <1.37.0"],
        "kinesis-video-archived-media": [
            "mypy-boto3-kinesis-video-archived-media>=1.36.0, <1.37.0"
        ],
        "kinesis-video-media": ["mypy-boto3-kinesis-video-media>=1.36.0, <1.37.0"],
        "kinesis-video-signaling": ["mypy-boto3-kinesis-video-signaling>=1.36.0, <1.37.0"],
        "kinesis-video-webrtc-storage": [
            "mypy-boto3-kinesis-video-webrtc-storage>=1.36.0, <1.37.0"
        ],
        "kinesisanalytics": ["mypy-boto3-kinesisanalytics>=1.36.0, <1.37.0"],
        "kinesisanalyticsv2": ["mypy-boto3-kinesisanalyticsv2>=1.36.0, <1.37.0"],
        "kinesisvideo": ["mypy-boto3-kinesisvideo>=1.36.0, <1.37.0"],
        "kms": ["mypy-boto3-kms>=1.36.0, <1.37.0"],
        "lakeformation": ["mypy-boto3-lakeformation>=1.36.0, <1.37.0"],
        "lambda": ["mypy-boto3-lambda>=1.36.0, <1.37.0"],
        "launch-wizard": ["mypy-boto3-launch-wizard>=1.36.0, <1.37.0"],
        "lex-models": ["mypy-boto3-lex-models>=1.36.0, <1.37.0"],
        "lex-runtime": ["mypy-boto3-lex-runtime>=1.36.0, <1.37.0"],
        "lexv2-models": ["mypy-boto3-lexv2-models>=1.36.0, <1.37.0"],
        "lexv2-runtime": ["mypy-boto3-lexv2-runtime>=1.36.0, <1.37.0"],
        "license-manager": ["mypy-boto3-license-manager>=1.36.0, <1.37.0"],
        "license-manager-linux-subscriptions": [
            "mypy-boto3-license-manager-linux-subscriptions>=1.36.0, <1.37.0"
        ],
        "license-manager-user-subscriptions": [
            "mypy-boto3-license-manager-user-subscriptions>=1.36.0, <1.37.0"
        ],
        "lightsail": ["mypy-boto3-lightsail>=1.36.0, <1.37.0"],
        "location": ["mypy-boto3-location>=1.36.0, <1.37.0"],
        "logs": ["mypy-boto3-logs>=1.36.0, <1.37.0"],
        "lookoutequipment": ["mypy-boto3-lookoutequipment>=1.36.0, <1.37.0"],
        "lookoutmetrics": ["mypy-boto3-lookoutmetrics>=1.36.0, <1.37.0"],
        "lookoutvision": ["mypy-boto3-lookoutvision>=1.36.0, <1.37.0"],
        "m2": ["mypy-boto3-m2>=1.36.0, <1.37.0"],
        "machinelearning": ["mypy-boto3-machinelearning>=1.36.0, <1.37.0"],
        "macie2": ["mypy-boto3-macie2>=1.36.0, <1.37.0"],
        "mailmanager": ["mypy-boto3-mailmanager>=1.36.0, <1.37.0"],
        "managedblockchain": ["mypy-boto3-managedblockchain>=1.36.0, <1.37.0"],
        "managedblockchain-query": ["mypy-boto3-managedblockchain-query>=1.36.0, <1.37.0"],
        "marketplace-agreement": ["mypy-boto3-marketplace-agreement>=1.36.0, <1.37.0"],
        "marketplace-catalog": ["mypy-boto3-marketplace-catalog>=1.36.0, <1.37.0"],
        "marketplace-deployment": ["mypy-boto3-marketplace-deployment>=1.36.0, <1.37.0"],
        "marketplace-entitlement": ["mypy-boto3-marketplace-entitlement>=1.36.0, <1.37.0"],
        "marketplace-reporting": ["mypy-boto3-marketplace-reporting>=1.36.0, <1.37.0"],
        "marketplacecommerceanalytics": [
            "mypy-boto3-marketplacecommerceanalytics>=1.36.0, <1.37.0"
        ],
        "mediaconnect": ["mypy-boto3-mediaconnect>=1.36.0, <1.37.0"],
        "mediaconvert": ["mypy-boto3-mediaconvert>=1.36.0, <1.37.0"],
        "medialive": ["mypy-boto3-medialive>=1.36.0, <1.37.0"],
        "mediapackage": ["mypy-boto3-mediapackage>=1.36.0, <1.37.0"],
        "mediapackage-vod": ["mypy-boto3-mediapackage-vod>=1.36.0, <1.37.0"],
        "mediapackagev2": ["mypy-boto3-mediapackagev2>=1.36.0, <1.37.0"],
        "mediastore": ["mypy-boto3-mediastore>=1.36.0, <1.37.0"],
        "mediastore-data": ["mypy-boto3-mediastore-data>=1.36.0, <1.37.0"],
        "mediatailor": ["mypy-boto3-mediatailor>=1.36.0, <1.37.0"],
        "medical-imaging": ["mypy-boto3-medical-imaging>=1.36.0, <1.37.0"],
        "memorydb": ["mypy-boto3-memorydb>=1.36.0, <1.37.0"],
        "meteringmarketplace": ["mypy-boto3-meteringmarketplace>=1.36.0, <1.37.0"],
        "mgh": ["mypy-boto3-mgh>=1.36.0, <1.37.0"],
        "mgn": ["mypy-boto3-mgn>=1.36.0, <1.37.0"],
        "migration-hub-refactor-spaces": [
            "mypy-boto3-migration-hub-refactor-spaces>=1.36.0, <1.37.0"
        ],
        "migrationhub-config": ["mypy-boto3-migrationhub-config>=1.36.0, <1.37.0"],
        "migrationhuborchestrator": ["mypy-boto3-migrationhuborchestrator>=1.36.0, <1.37.0"],
        "migrationhubstrategy": ["mypy-boto3-migrationhubstrategy>=1.36.0, <1.37.0"],
        "mq": ["mypy-boto3-mq>=1.36.0, <1.37.0"],
        "mturk": ["mypy-boto3-mturk>=1.36.0, <1.37.0"],
        "mwaa": ["mypy-boto3-mwaa>=1.36.0, <1.37.0"],
        "neptune": ["mypy-boto3-neptune>=1.36.0, <1.37.0"],
        "neptune-graph": ["mypy-boto3-neptune-graph>=1.36.0, <1.37.0"],
        "neptunedata": ["mypy-boto3-neptunedata>=1.36.0, <1.37.0"],
        "network-firewall": ["mypy-boto3-network-firewall>=1.36.0, <1.37.0"],
        "networkflowmonitor": ["mypy-boto3-networkflowmonitor>=1.36.0, <1.37.0"],
        "networkmanager": ["mypy-boto3-networkmanager>=1.36.0, <1.37.0"],
        "networkmonitor": ["mypy-boto3-networkmonitor>=1.36.0, <1.37.0"],
        "notifications": ["mypy-boto3-notifications>=1.36.0, <1.37.0"],
        "notificationscontacts": ["mypy-boto3-notificationscontacts>=1.36.0, <1.37.0"],
        "oam": ["mypy-boto3-oam>=1.36.0, <1.37.0"],
        "observabilityadmin": ["mypy-boto3-observabilityadmin>=1.36.0, <1.37.0"],
        "omics": ["mypy-boto3-omics>=1.36.0, <1.37.0"],
        "opensearch": ["mypy-boto3-opensearch>=1.36.0, <1.37.0"],
        "opensearchserverless": ["mypy-boto3-opensearchserverless>=1.36.0, <1.37.0"],
        "opsworks": ["mypy-boto3-opsworks>=1.36.0, <1.37.0"],
        "opsworkscm": ["mypy-boto3-opsworkscm>=1.36.0, <1.37.0"],
        "organizations": ["mypy-boto3-organizations>=1.36.0, <1.37.0"],
        "osis": ["mypy-boto3-osis>=1.36.0, <1.37.0"],
        "outposts": ["mypy-boto3-outposts>=1.36.0, <1.37.0"],
        "panorama": ["mypy-boto3-panorama>=1.36.0, <1.37.0"],
        "partnercentral-selling": ["mypy-boto3-partnercentral-selling>=1.36.0, <1.37.0"],
        "payment-cryptography": ["mypy-boto3-payment-cryptography>=1.36.0, <1.37.0"],
        "payment-cryptography-data": ["mypy-boto3-payment-cryptography-data>=1.36.0, <1.37.0"],
        "pca-connector-ad": ["mypy-boto3-pca-connector-ad>=1.36.0, <1.37.0"],
        "pca-connector-scep": ["mypy-boto3-pca-connector-scep>=1.36.0, <1.37.0"],
        "pcs": ["mypy-boto3-pcs>=1.36.0, <1.37.0"],
        "personalize": ["mypy-boto3-personalize>=1.36.0, <1.37.0"],
        "personalize-events": ["mypy-boto3-personalize-events>=1.36.0, <1.37.0"],
        "personalize-runtime": ["mypy-boto3-personalize-runtime>=1.36.0, <1.37.0"],
        "pi": ["mypy-boto3-pi>=1.36.0, <1.37.0"],
        "pinpoint": ["mypy-boto3-pinpoint>=1.36.0, <1.37.0"],
        "pinpoint-email": ["mypy-boto3-pinpoint-email>=1.36.0, <1.37.0"],
        "pinpoint-sms-voice": ["mypy-boto3-pinpoint-sms-voice>=1.36.0, <1.37.0"],
        "pinpoint-sms-voice-v2": ["mypy-boto3-pinpoint-sms-voice-v2>=1.36.0, <1.37.0"],
        "pipes": ["mypy-boto3-pipes>=1.36.0, <1.37.0"],
        "polly": ["mypy-boto3-polly>=1.36.0, <1.37.0"],
        "pricing": ["mypy-boto3-pricing>=1.36.0, <1.37.0"],
        "privatenetworks": ["mypy-boto3-privatenetworks>=1.36.0, <1.37.0"],
        "proton": ["mypy-boto3-proton>=1.36.0, <1.37.0"],
        "qapps": ["mypy-boto3-qapps>=1.36.0, <1.37.0"],
        "qbusiness": ["mypy-boto3-qbusiness>=1.36.0, <1.37.0"],
        "qconnect": ["mypy-boto3-qconnect>=1.36.0, <1.37.0"],
        "qldb": ["mypy-boto3-qldb>=1.36.0, <1.37.0"],
        "qldb-session": ["mypy-boto3-qldb-session>=1.36.0, <1.37.0"],
        "quicksight": ["mypy-boto3-quicksight>=1.36.0, <1.37.0"],
        "ram": ["mypy-boto3-ram>=1.36.0, <1.37.0"],
        "rbin": ["mypy-boto3-rbin>=1.36.0, <1.37.0"],
        "rds": ["mypy-boto3-rds>=1.36.0, <1.37.0"],
        "rds-data": ["mypy-boto3-rds-data>=1.36.0, <1.37.0"],
        "redshift": ["mypy-boto3-redshift>=1.36.0, <1.37.0"],
        "redshift-data": ["mypy-boto3-redshift-data>=1.36.0, <1.37.0"],
        "redshift-serverless": ["mypy-boto3-redshift-serverless>=1.36.0, <1.37.0"],
        "rekognition": ["mypy-boto3-rekognition>=1.36.0, <1.37.0"],
        "repostspace": ["mypy-boto3-repostspace>=1.36.0, <1.37.0"],
        "resiliencehub": ["mypy-boto3-resiliencehub>=1.36.0, <1.37.0"],
        "resource-explorer-2": ["mypy-boto3-resource-explorer-2>=1.36.0, <1.37.0"],
        "resource-groups": ["mypy-boto3-resource-groups>=1.36.0, <1.37.0"],
        "resourcegroupstaggingapi": ["mypy-boto3-resourcegroupstaggingapi>=1.36.0, <1.37.0"],
        "robomaker": ["mypy-boto3-robomaker>=1.36.0, <1.37.0"],
        "rolesanywhere": ["mypy-boto3-rolesanywhere>=1.36.0, <1.37.0"],
        "route53": ["mypy-boto3-route53>=1.36.0, <1.37.0"],
        "route53-recovery-cluster": ["mypy-boto3-route53-recovery-cluster>=1.36.0, <1.37.0"],
        "route53-recovery-control-config": [
            "mypy-boto3-route53-recovery-control-config>=1.36.0, <1.37.0"
        ],
        "route53-recovery-readiness": ["mypy-boto3-route53-recovery-readiness>=1.36.0, <1.37.0"],
        "route53domains": ["mypy-boto3-route53domains>=1.36.0, <1.37.0"],
        "route53profiles": ["mypy-boto3-route53profiles>=1.36.0, <1.37.0"],
        "route53resolver": ["mypy-boto3-route53resolver>=1.36.0, <1.37.0"],
        "rum": ["mypy-boto3-rum>=1.36.0, <1.37.0"],
        "s3": ["mypy-boto3-s3>=1.36.0, <1.37.0"],
        "s3control": ["mypy-boto3-s3control>=1.36.0, <1.37.0"],
        "s3outposts": ["mypy-boto3-s3outposts>=1.36.0, <1.37.0"],
        "s3tables": ["mypy-boto3-s3tables>=1.36.0, <1.37.0"],
        "sagemaker": ["mypy-boto3-sagemaker>=1.36.0, <1.37.0"],
        "sagemaker-a2i-runtime": ["mypy-boto3-sagemaker-a2i-runtime>=1.36.0, <1.37.0"],
        "sagemaker-edge": ["mypy-boto3-sagemaker-edge>=1.36.0, <1.37.0"],
        "sagemaker-featurestore-runtime": [
            "mypy-boto3-sagemaker-featurestore-runtime>=1.36.0, <1.37.0"
        ],
        "sagemaker-geospatial": ["mypy-boto3-sagemaker-geospatial>=1.36.0, <1.37.0"],
        "sagemaker-metrics": ["mypy-boto3-sagemaker-metrics>=1.36.0, <1.37.0"],
        "sagemaker-runtime": ["mypy-boto3-sagemaker-runtime>=1.36.0, <1.37.0"],
        "savingsplans": ["mypy-boto3-savingsplans>=1.36.0, <1.37.0"],
        "scheduler": ["mypy-boto3-scheduler>=1.36.0, <1.37.0"],
        "schemas": ["mypy-boto3-schemas>=1.36.0, <1.37.0"],
        "sdb": ["mypy-boto3-sdb>=1.36.0, <1.37.0"],
        "secretsmanager": ["mypy-boto3-secretsmanager>=1.36.0, <1.37.0"],
        "security-ir": ["mypy-boto3-security-ir>=1.36.0, <1.37.0"],
        "securityhub": ["mypy-boto3-securityhub>=1.36.0, <1.37.0"],
        "securitylake": ["mypy-boto3-securitylake>=1.36.0, <1.37.0"],
        "serverlessrepo": ["mypy-boto3-serverlessrepo>=1.36.0, <1.37.0"],
        "service-quotas": ["mypy-boto3-service-quotas>=1.36.0, <1.37.0"],
        "servicecatalog": ["mypy-boto3-servicecatalog>=1.36.0, <1.37.0"],
        "servicecatalog-appregistry": ["mypy-boto3-servicecatalog-appregistry>=1.36.0, <1.37.0"],
        "servicediscovery": ["mypy-boto3-servicediscovery>=1.36.0, <1.37.0"],
        "ses": ["mypy-boto3-ses>=1.36.0, <1.37.0"],
        "sesv2": ["mypy-boto3-sesv2>=1.36.0, <1.37.0"],
        "shield": ["mypy-boto3-shield>=1.36.0, <1.37.0"],
        "signer": ["mypy-boto3-signer>=1.36.0, <1.37.0"],
        "simspaceweaver": ["mypy-boto3-simspaceweaver>=1.36.0, <1.37.0"],
        "sms": ["mypy-boto3-sms>=1.36.0, <1.37.0"],
        "sms-voice": ["mypy-boto3-sms-voice>=1.36.0, <1.37.0"],
        "snow-device-management": ["mypy-boto3-snow-device-management>=1.36.0, <1.37.0"],
        "snowball": ["mypy-boto3-snowball>=1.36.0, <1.37.0"],
        "sns": ["mypy-boto3-sns>=1.36.0, <1.37.0"],
        "socialmessaging": ["mypy-boto3-socialmessaging>=1.36.0, <1.37.0"],
        "sqs": ["mypy-boto3-sqs>=1.36.0, <1.37.0"],
        "ssm": ["mypy-boto3-ssm>=1.36.0, <1.37.0"],
        "ssm-contacts": ["mypy-boto3-ssm-contacts>=1.36.0, <1.37.0"],
        "ssm-incidents": ["mypy-boto3-ssm-incidents>=1.36.0, <1.37.0"],
        "ssm-quicksetup": ["mypy-boto3-ssm-quicksetup>=1.36.0, <1.37.0"],
        "ssm-sap": ["mypy-boto3-ssm-sap>=1.36.0, <1.37.0"],
        "sso": ["mypy-boto3-sso>=1.36.0, <1.37.0"],
        "sso-admin": ["mypy-boto3-sso-admin>=1.36.0, <1.37.0"],
        "sso-oidc": ["mypy-boto3-sso-oidc>=1.36.0, <1.37.0"],
        "stepfunctions": ["mypy-boto3-stepfunctions>=1.36.0, <1.37.0"],
        "storagegateway": ["mypy-boto3-storagegateway>=1.36.0, <1.37.0"],
        "sts": ["mypy-boto3-sts>=1.36.0, <1.37.0"],
        "supplychain": ["mypy-boto3-supplychain>=1.36.0, <1.37.0"],
        "support": ["mypy-boto3-support>=1.36.0, <1.37.0"],
        "support-app": ["mypy-boto3-support-app>=1.36.0, <1.37.0"],
        "swf": ["mypy-boto3-swf>=1.36.0, <1.37.0"],
        "synthetics": ["mypy-boto3-synthetics>=1.36.0, <1.37.0"],
        "taxsettings": ["mypy-boto3-taxsettings>=1.36.0, <1.37.0"],
        "textract": ["mypy-boto3-textract>=1.36.0, <1.37.0"],
        "timestream-influxdb": ["mypy-boto3-timestream-influxdb>=1.36.0, <1.37.0"],
        "timestream-query": ["mypy-boto3-timestream-query>=1.36.0, <1.37.0"],
        "timestream-write": ["mypy-boto3-timestream-write>=1.36.0, <1.37.0"],
        "tnb": ["mypy-boto3-tnb>=1.36.0, <1.37.0"],
        "transcribe": ["mypy-boto3-transcribe>=1.36.0, <1.37.0"],
        "transfer": ["mypy-boto3-transfer>=1.36.0, <1.37.0"],
        "translate": ["mypy-boto3-translate>=1.36.0, <1.37.0"],
        "trustedadvisor": ["mypy-boto3-trustedadvisor>=1.36.0, <1.37.0"],
        "verifiedpermissions": ["mypy-boto3-verifiedpermissions>=1.36.0, <1.37.0"],
        "voice-id": ["mypy-boto3-voice-id>=1.36.0, <1.37.0"],
        "vpc-lattice": ["mypy-boto3-vpc-lattice>=1.36.0, <1.37.0"],
        "waf": ["mypy-boto3-waf>=1.36.0, <1.37.0"],
        "waf-regional": ["mypy-boto3-waf-regional>=1.36.0, <1.37.0"],
        "wafv2": ["mypy-boto3-wafv2>=1.36.0, <1.37.0"],
        "wellarchitected": ["mypy-boto3-wellarchitected>=1.36.0, <1.37.0"],
        "wisdom": ["mypy-boto3-wisdom>=1.36.0, <1.37.0"],
        "workdocs": ["mypy-boto3-workdocs>=1.36.0, <1.37.0"],
        "workmail": ["mypy-boto3-workmail>=1.36.0, <1.37.0"],
        "workmailmessageflow": ["mypy-boto3-workmailmessageflow>=1.36.0, <1.37.0"],
        "workspaces": ["mypy-boto3-workspaces>=1.36.0, <1.37.0"],
        "workspaces-thin-client": ["mypy-boto3-workspaces-thin-client>=1.36.0, <1.37.0"],
        "workspaces-web": ["mypy-boto3-workspaces-web>=1.36.0, <1.37.0"],
        "xray": ["mypy-boto3-xray>=1.36.0, <1.37.0"],
    },
    zip_safe=False,
)
